==> nextcloud-27.1.3.tgz: nextcloud/apps/weather_status/l10n/id.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Alamat tidak diketahui",
    "No result." : "Tidak ada hasil.",
    "Malformed JSON data." : "Data JSON tidak terbentuk dengan benar.",
    "Error" : "Galat",
    "Weather status" : "Status cuaca",
    "Weather status in your dashboard" : "Status cuaca di dasbor Anda",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Status pengguna terintegrasi dalam aplikasi Dasbor.\n    Posisi pengguna dapat ditentukan secara otomatis atau secara manual. Sebuah prakiraan 6 jam akan ditampilkan.\n    Status ini juga dapat diintegrasikan di tempat lain seperti aplikasi Kalender.",
    "Detect location" : "Deteksi lokasi",
    "Set custom address" : "Tetapkan alamat kustom",
    "Favorites" : "Disukai",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} langit cerah nanti pada hari ini",
    "{temperature} {unit} clear sky" : "{temperature} {unit} langit cerah",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} berawan nanti pada hari ini",
    "{temperature} {unit} cloudy" : "{temperature} {unit} berawan",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} cuaca cerah nanti pada hari ini",
    "{temperature} {unit} fair weather" : "{temperature} {unit} cuaca cerah",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} sebagian berawan nanti pada hari ini",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} sebagian berawan",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} berkabut nanti pada hari ini",
    "{temperature} {unit} foggy" : "{temperature} {unit} berkabut",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} hujan ringan nanti pada hari ini",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} hujan ringan",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} hujan nanti pada hari ini",
    "{temperature} {unit} rainfall" : "{temperature} {unit} hujan",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} hujan deras nanti pada hari ini",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} hujan deras",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} rintik hujan nanti pada hari ini",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} rintik hujan",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} rintik hujan ringan nanti pada hari ini",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} rintik hujan ringan",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} rintik hujan deras nanti pada hari ini",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} rintik hujan deras",
    "More weather for {adr}" : "Lebih banyak cuaca untuk {adr}",
    "Loading weather" : "Memuat cuaca",
    "Remove from favorites" : "Remove from favorites",
    "Add as favorite" : "Tambahkan sebagai favorit",
    "You are not logged in." : "Anda belum masuk.",
    "There was an error getting the weather status information." : "Ada kesalahan mendapatkan informasi status cuaca.",
    "No weather information found" : "Tidak ada informasi cuaca yang ditemukan",
    "Location not found" : "Lokasi tidak ditemukan",
    "There was an error setting the location address." : "Ada kesalahan menetapkan alamat lokasi.",
    "There was an error setting the location." : "Ada kesalahan menetapkan lokasi.",
    "There was an error saving the mode." : "Ada kesalahan menyimpan mode.",
    "There was an error using personal address." : "Ada kesalahan menggunakan alamat pribadi.",
    "Set location for weather" : "Atur lokasi untuk cuaca"
},
"nplurals=1; plural=0;");

==> nextcloud-27.1.11.tgz: nextcloud/apps/weather_status/l10n/id.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Alamat tidak diketahui",
    "No result." : "Tidak ada hasil.",
    "Malformed JSON data." : "Data JSON tidak terbentuk dengan benar.",
    "Error" : "Galat",
    "Weather status" : "Status cuaca",
    "Weather status in your dashboard" : "Status cuaca di dasbor Anda",
    "Detect location" : "Deteksi lokasi",
    "Set custom address" : "Tetapkan alamat kustom",
    "Favorites" : "Disukai",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} langit cerah nanti pada hari ini",
    "{temperature} {unit} clear sky" : "{temperature} {unit} langit cerah",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} berawan nanti pada hari ini",
    "{temperature} {unit} cloudy" : "{temperature} {unit} berawan",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} cuaca cerah nanti pada hari ini",
    "{temperature} {unit} fair weather" : "{temperature} {unit} cuaca cerah",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} sebagian berawan nanti pada hari ini",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} sebagian berawan",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} berkabut nanti pada hari ini",
    "{temperature} {unit} foggy" : "{temperature} {unit} berkabut",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} hujan ringan nanti pada hari ini",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} hujan ringan",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} hujan nanti pada hari ini",
    "{temperature} {unit} rainfall" : "{temperature} {unit} hujan",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} hujan deras nanti pada hari ini",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} hujan deras",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} rintik hujan nanti pada hari ini",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} rintik hujan",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} rintik hujan ringan nanti pada hari ini",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} rintik hujan ringan",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} rintik hujan deras nanti pada hari ini",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} rintik hujan deras",
    "More weather for {adr}" : "Lebih banyak cuaca untuk {adr}",
    "Loading weather" : "Memuat cuaca",
    "Remove from favorites" : "Remove from favorites",
    "Add as favorite" : "Tambahkan sebagai favorit",
    "You are not logged in." : "Anda belum masuk.",
    "There was an error getting the weather status information." : "Ada kesalahan mendapatkan informasi status cuaca.",
    "No weather information found" : "Tidak ada informasi cuaca yang ditemukan",
    "Location not found" : "Lokasi tidak ditemukan",
    "There was an error setting the location address." : "Ada kesalahan menetapkan alamat lokasi.",
    "There was an error setting the location." : "Ada kesalahan menetapkan lokasi.",
    "There was an error saving the mode." : "Ada kesalahan menyimpan mode.",
    "There was an error using personal address." : "Ada kesalahan menggunakan alamat pribadi.",
    "Set location for weather" : "Atur lokasi untuk cuaca",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Status pengguna terintegrasi dalam aplikasi Dasbor.\n    Posisi pengguna dapat ditentukan secara otomatis atau secara manual. Sebuah prakiraan 6 jam akan ditampilkan.\n    Status ini juga dapat diintegrasikan di tempat lain seperti aplikasi Kalender."
},
"nplurals=1; plural=0;");
